#
# spec file for package simplescreenrecorder
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           simplescreenrecorder
Version:        0.4.4
Release:        2.11
Summary:        A feature-rich screen recorder that supports X11 and OpenGL
License:        GPL-3.0-or-later
Group:          System/X11/Utilities
URL:            http://www.maartenbaert.be/simplescreenrecorder
Source:         https://github.com/MaartenBaert/ssr/archive/%{version}.tar.gz
Source9:        baselibs.conf
# PATCH-FIX-UPSTREAM badshah400@gmail.com -- Compatibility for newer ffmpeg (>=4); patch taken from upstream git commit
Patch0:         https://github.com/MaartenBaert/ssr/commit/768957a8de1534f0aa91bfc5d7af3c32f222beb8.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libjpeg8-devel
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Gui)       >= 5.7
BuildRequires:  pkgconfig(Qt5Widgets)   >= 5.7
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.7
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec) >= 53
BuildRequires:  pkgconfig(libavformat) >= 53
BuildRequires:  pkgconfig(libavutil) >= 51
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswscale) >= 2
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
%ifarch %{ix86} x86_64
# openGL apps:
Recommends:     libssr-glinject
%if "%{_lib}" == "lib64"
# 32bit openGL apps at 64bit system:
Suggests:       libssr-glinject-32bit
%endif
%endif

%description
SimpleScreenRecorder is a Linux program that was created to record programs
and games.

The original goal was to create a program that was just really simple to
use, the result is actually a pretty powerful program. It's 'simple' in
the sense that it's easier to use than ffmpeg/avconv or VLC, because it
has a straightforward user interface.

Features:
 * Graphical user interface (Qt-based).
 * Faster than VLC and ffmpeg/avconv.
 * Records the entire screen or part of it, or records OpenGL applications
   directly (similar to Fraps on Windows).
 * Synchronizes audio and video properly (a common issue with VLC and
   ffmpeg/avconv).
 * Reduces the video frame rate if your computer is too slow (rather than
   using up all your RAM like VLC does).
 * Fully multithreaded: small delays in any of the components will never
   block the other components, resulting is smoother video and better
   performance on computers with multiple processors.
 * Pause and resume recording at any time (either by clicking a button or by
   pressing a hotkey).
 * Shows statistics during recording (file size, bit rate, total recording
   time, actual frame rate, ...).
 * Can show a preview during recording, so you don't waste time recording
   something only to figure out afterwards that some setting was wrong.
 * Uses libav/ffmpeg libraries for encoding, so it supports many different
   codecs and file formats (adding more is trivial).
 * Sensible default settings: no need to change anything if you don't want to.
 * Tooltips for almost everything: no need to read the documentation to find
   out what something does.


%ifarch %{ix86} x86_64
%package -n libssr-glinject
Summary:        Simple Screen Recorder openGL plugin
License:        MIT
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libssr-glinject
This package provides nice openGL apps screencasting support
for Simple Screen Recorder. At 64bit system you may also
install libssr-glinject-32bit for 32bit openGL apps support.
%endif

%prep
%autosetup -p1 -n ssr-%{version}

%build
%ifarch %{ix86} x86_64
# /usr/include/qt5/QtCore/qglobal.h:1067:4: error: error "You must build
# your code with position independent code if Qt was built with
# -reduce-relocations. " "Compile your code with -fPIC (-fPIE is not
# enough)." error "You must build your code with position independent code
# if Qt was built with -reduce-relocations."
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%cmake -DWITH_QT5=True
%else
%cmake \
       -DWITH_QT5=True \
       -DWITH_GLINJECT=False
%endif
make V=1 %{?_smp_mflags}

%install
%cmake_install
%fdupes -s %{buildroot}%{_datadir}/icons/hicolor
%suse_update_desktop_file %{name}

%files
%defattr(-,root,root)
%doc *.txt *.md data/resources/about.htm
%license COPYING
%{_bindir}/%{name}
%{_bindir}/ssr-glinject
%{_datadir}/metainfo/%{name}.metainfo.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/%{name}
%{_mandir}/*/%{name}*
%{_mandir}/*/ssr-glinject*

%ifarch %{ix86} x86_64
%files -n libssr-glinject
%defattr(-,root,root)
%{_libdir}/libssr-glinject.so
%endif

%changelog
* Mon Aug  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add 768957a8de1534f0aa91bfc5d7af3c32f222beb8.patch: fix building
  against newer ffmpeg (>= 5.0); patch taken from upstream git
  commit.
* Wed May 18 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.4.4:
  + Some minor improvements.
  + Bugfixes.
  + Updated translations.
* Mon Jan 11 2021 Dirk Mueller <dmueller@suse.com>
- update to 0.4.3:
  * Added V4L2 support (most webcams and capture cards).
  * Added option to mark recorded area on screen during recording.
  * Added JACK metadata.
  * Optionally support XDG config directory (~/.config/simplescreenrecorder) instead of home directory (~/.ssr).
  * Bugfixes.
* Thu May 21 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Update to 0.4.2 (since 0.4.1):
  * Improved X11/Wayland detection.
  * Changed ALSA input to use non-blocking API to reduce the latency.
  * Added support for s24, s32 and f32 sample formats for ALSA input.
  * Added 'open folder' button after saving the recording.
  * Several minor improvements.
* Fri May  1 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Update to 0.4.1 (since 0.4.0):
  * Added warning for Wayland users.
  * Error messages from libraries are now shown in the log window.
  * Fixed blocked continue button after selecting a window.
* Fri Apr 10 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Update to 0.4.0 (since 0.3.11):
  * Use av_muxer_iterate/av_codec_iterate instead of av_oformat_next/av_c.
  * Added support for Serbian language.
  * Mouse grabbing when SSR loses focus while selecting a rectangle/w.
  * Try to disable high-DPI scaling since it breaks too many things in SSR.
  * Rename EventData for consistency.*
  * Use the X11 Xinerama extension to get screen resolutions in X11Input.*
  * High-DPI drawing for VideoPreviewer.
  * High DPI support for PageInput.
  * Follow mouse mode in X11input.
  * Add 'follow fullscreen' recording mode to X11Input.
  * Update translations.
  * Actually in X11Input dead space calculation.
  * Add missing tooltips.
  * Improve appearance for non-integer scale factors.
  * Automatically use the right version of lrelease.
  * Add option to skip the welcome page.
  * Add xinerama build dep.
  * Increase maximum image size to 20000x20000.
  * Add screenshot to readme.
  * Update copyright year.
  * Improve command-line option parsing, add option to change settings file.
  * Add option to start recording immediately after launch.
  * Add recording schedule.
  * Add option to start schedule automatically.
  * Add command-line control over stdin.
  * Reentrancy problem in stdin handler.
  * Change default hotkey t.
- Fixed W: empty-%%post & W: empty-%%postun.
* Sun Jun 10 2018 dap.darkness@gmail.com
- Update to 0.3.11 (since 0.3.8):
  * Fixed FFmpeg 4.0 compatibility.
  * Fixed AAC codec (missing channel layout).
  * Improved build system.
  * Custom recording frame to replace QRubberBand (for Qt5).
  * Improved build system.
  * Switch to CMake build system.
  * Add RGB24 support.
  * Automatically add scroll bars.
  * Improve PulseAudio latency handling of monitors.
  * Add a separate checkbox to enable timestamps.
  * All options are set to a sensible default value.
  * Use base-10 units for bitrate for consistency with FFmpeg.
  * Minor bugfixes.
* Tue Nov 15 2016 dap.darkness@gmail.com
- Update to 0.3.8 (since 0.3.7):
  * Revert sample rate to 44.1 kHz for FLV container.
* Sun Oct 16 2016 dap.darkness@gmail.com
- Update to 0.3.7 (since 0.3.6):
  * Added support for latest FFmpeg/libav.
  * Make relaxed GLInject permissions actually work.
  * The backend now supports fragmented recording,
    but there is no GUI for this yet.
  * The default audio sample rate is now 48 kHz.
    This makes SSR compatible with Opus.
  * System tray icon now indicates errors during recording.
- Removed simplescreenrecorder-0.3.6-missing-include.diff
  as already provided via upstream tarball.
* Fri Jun 17 2016 dap.darkness@gmail.com
- `spec-cleaner`
- Added simplescreenrecorder-0.3.6-missing-include.diff
  to resolve bnc#985369.
- Tips from Packman's package.
- Enabled verbose make build.
* Tue Nov  3 2015 dap.darkness@gmail.com
- Update to 0.3.6 (since 0.3.3):
  * Fix bug in YUV420 fallback converter introduced by refactoring.
  * Allow user to start recording with hotkey or systray even when
    not on the recording page.
  * Fixed JACK input bug that could cause deadlocks in rare cases.
  * Added full support for NV12. If FFmpeg is compiled with NVENC
    support, this will allow you to use it.
  * Removed ssr-0.3.3-fix-disable-x86-asm.diff as merged.
  * Removed ssr-0.3.3-ffmpeg-pkgconfig.diff as merged by upstream.
- Qt4 → Qt5.
* Fri May  1 2015 dap.darkness@gmail.com
- baselibs.conf became mentioned in spec files as source
  to pass factory-auto.
* Mon Apr 27 2015 dap.darkness@gmail.com
- Fixed up libssr-glinject subpackage description (request#303989).
- Removed libssr-glinject static build (request#303989).
- Let's only suggest libssr-glinject-32bit to not install 32bit
  dependencies with default ssr installation.
- Dropped openSUSE < 13.* support.
* Thu Apr 23 2015 dap.darkness@gmail.com
- Packman → OBS;
- _service → tarball;
- `spec-cleaner`.
- Added ssr-0.3.3-ffmpeg-pkgconfig.diff
  to make build against openSUSE' ffmpeg possible
  ( https://github.com/MaartenBaert/ssr/commit/5929b ).
* Sat Jan 17 2015 dap.darkness@gmail.com
- Update to 0.3.3:
  * Fixed mistake in configure.ac that was causing
    libssr-glinject.so to be linked with unwanted libraries.
- Added ssr-0.3.3-fix-disable-x86-asm.patch.diff
  to fix --disable-x86-asm option
  ( https://github.com/MaartenBaert/ssr/commit/8043 ).
* Mon Jan  5 2015 dap.darkness@gmail.com
- Update to 0.3.2:
  * Added Qt5 support (optional, Qt4 is still the default).
  * Added YUV422, YUV444 and RGB support
    (YUV420 is still the default)
  * Added pixelformat and sampleformat codec options.
  * Added benchmark.
  * Improved RTL support.
  * Bugfixes.
* Fri Oct  3 2014 dap.darkness@gmail.com
- Update to 0.3.1:
  * no upstream changelog.
* Thu Jul  3 2014 dap.darkness@gmail.com
- Update to 0.3.0:
  * Added profile support.
  * New, more flexible OpenGL recording system
    (glinject-next branch merged).
  * More robust sound notifications.
  * Show progress dialog while flushing the encoders.
  * Improved hotkey support using XInput2.
  * Improved synchronizer.
  * Native support for mono microphones (plughw no longer needed).
  * Added source detection for ALSA.
  * Partially rewritten output backend.
  * Improved mouse following algorithm.
  * New icon.
  * Bugfixes.
* Tue Mar  4 2014 dap.darkness@gmail.com
- Update to 0.2.2:
  * Fix bug in Synchronizer that caused throttling to fail,
    resulting in excessive memory usage.
- Switching back to _service.
* Sun Mar  2 2014 dap.darkness@gmail.com
- Update to 0.2.1+git.2014.03.02:
  * Avoid build warning when assertions are disabled
  * Make sure that the resampler is only created when audio is
    enabled.
- Update to 0.2.1:
  * Correction to command-line help message.
  * Fix minor bug in drift recalculation in Synchronizer.
  * Bugfix: Don't stop the muxer before all packet queues
    are empty.
  * Make timestamps in file names Windows-compatible.
  * Make sure the segment is complete before destroying the
    synchronizer (shouldn't make a huge difference but let's do it
    anyway).
  * Add icons to distribution tarball.
- desktop_database_post(un) & icon_theme_cache_post(un)
  macros were added.
- enable-jack configure option was deleted as default.
- Temporary switching from _service to git tarball.
* Sat Feb 22 2014 dap.darkness@gmail.com
- Update to 0.2.0:
  * no upstream changelog.
- Switching back to _service.
* Wed Feb 12 2014 dap.darkness@gmail.com
- Update to 0.1.2+git.2014.02.09:
  * Jack support;
  * SoX Resampler became used;
  * cmake became used;
  * pkg-config became used;
  * "[VideoEncoder::EncodeFrame] Error: Keyframe flag was not set!"
    was fixed.
- Temporary switching from _service to git tarball.
* Mon Oct 28 2013 dap.darkness@gmail.com
- Update to 0.1.2:
  * no upstream changelog.
- Switched to configure option using instead of CPPFLAGS modifying.
* Sat Oct 19 2013 dap.darkness@gmail.com
- Update to 0.1.1:
  * no upstream changelog.
- Not exclude arm but include x86* only.
* Wed Sep 25 2013 dap.darkness@gmail.com
- Update to 0.1.0:
  * no upstream changelog.
- libssr-glinject-32bit became built and recommended
  to record x32 games at x64 hosts.
- libssr-glinject can't be built for arm:
  https://github.com/MaartenBaert/ssr/issues/30
- Service source_validator was removed because of
  https://bugs.links2linux.org/browse/PM-83
* Tue Jun 11 2013 dap.darkness@gmail.com
- Initial package.
